@@ -6,7 +6,6 @@ use App::gh::Utils;
 use File::stat;
 use File::Temp;
 use Text::Wrap;
-use IO::Pager;
 require App::gh::Git;
 
 
@@ -43,6 +42,7 @@ sub get_remote {
 sub run {
     my $self = shift;
 
+
     my $remote = $self->get_remote();
 
     die "Remote not found\n." unless $remote;
@@ -54,11 +54,15 @@ sub run {
         die "Github authtoken not found. Can not get pull requests.\n";
     }
 
+
     my $data = App::gh->api->pullreq_list( $user, $repo );
     unless (@{$data->{pulls}}) {
         _info "No pull request found.";
     } else {
-        local  $STDOUT = new IO::Pager       *STDOUT;
+        eval { require IO::Pager; };
+        unless ($@) {
+            local $STDOUT = new IO::Pager *STDOUT;
+        }
         for my $pull (@{$data->{pulls}}) {
             printf "* Issue %d: %s - %s (%s)\n", $pull->{number} , 
                 $pull->{title},
